Module address

Module address 

Block identifiers and chunk address types.

A ChunkAddress locates a slice of array data within a specific block by (block_id, offset, size).

Structs

ArchivedBlockId
An archived BlockId
ArchivedChunkAddress
An archived ChunkAddress
BlockId
A block identifier within the file.
BlockIdResolver
The resolver for an archived BlockId
ChunkAddress
Locates a contiguous slice of bytes within a block.
ChunkAddressResolver
The resolver for an archived ChunkAddress