Module codec

Module codec 

Compression codec trait and built-in implementations.

The CompressionCodec trait allows plugging in different compression algorithms. The footer records which codec was used per block via CodecId, so the reader must be configured with a codec that can handle all codec ids present in the file.

Structs

Lz4Codec
LZ4 compression codec using lz4_flex.
NoCompression
A no-op codec that stores blocks uncompressed.
ZstdCodec
Zstandard compression codec.

Traits

CompressionCodec
A compression codec that can compress and decompress block data.

Functions

decompress_by_id
Decompresses data by dispatching on the CodecId stored in the block footer.