Module delta

Module delta 

Re-exports

pub use cache::DeltaCache;

Modules

cache

Structs

AllocatorOutput
The output of DeltaAllocator::commit: a file handle to the compressed block bytes (seeked to the start), the total byte count, and the block metadata table.
Delta
DeltaAllocator
Packs raw chunk bytes into compressed blocks.
DeltaImmutable
DeltaMutable