Error

Enum Error 

pub enum Error {
    Io(Error),
    Serialization(String),
    InvalidFooter(String),
    ArrayNotFound {
        name: String,
    },
    BlockOutOfRange {
        block_id: u32,
    },
    Codec(String),
    Storage(String),
    ArrayAlreadyExists {
        name: String,
    },
    DTypeMismatch {
        expected: DType,
        actual: DType,
    },
}
The error type for array-format operations.

Variants



Io(Error)

I/O error from the underlying storage backend.



Serialization(String)

Footer serialization or deserialization failed.



InvalidFooter(String)

The file footer is invalid or corrupt.



ArrayNotFound

The requested array was not found.

Fields

name: String

Name of the array that was not found.



BlockOutOfRange

A referenced block id is out of range.

Fields

block_id: u32

The invalid block id.



Codec(String)

Compression or decompression failed.



Storage(String)

Storage backend error.



ArrayAlreadyExists

The array already exists.

Fields

name: String

Name of the duplicate array.



DTypeMismatch

The dtype of the data does not match the dtype of the array.

Fields

expected: DType

The dtype declared in the array metadata.

actual: DType

The dtype of the data being read or written.