Module footer

Module footer 

File footer: the index that maps array names to block addresses.

The footer is appended at the end of the file. A 12-byte trailer (footer_size: u64 LE + MAGIC) allows the reader to locate and validate the footer from the tail of the file.

[footer_bytes][footer_size: u64 LE][MAGIC b"ARRF"]

Structs

ArchivedFooter
An archived Footer
Footer
The file footer containing the block table and array table.
FooterResolver
The resolver for an archived Footer

Constants

FOOTER_VERSION
Current footer format version.
MAGIC
Magic bytes written at the very end of the file.
TRAILER_SIZE
Size of the trailer in bytes (u64 footer size + 4-byte magic).

Functions

read_footer
Reads and deserializes the footer from storage.