Module storage

Module storage 

Storage backend trait and implementations.

The Storage trait abstracts file I/O so the format can work with local files, object stores, or in-memory buffers. An ObjectStoreBackend adapter is provided for the object_store crate, and InMemoryStorage is provided for testing.

Structs

InMemoryStorage
An in-memory storage backend for testing.
ObjectStoreBackend
A storage backend backed by an object_store::ObjectStore implementation.

Traits

MultipartWriter
Streaming writer used to build up a file in chunks.
Storage
Async storage backend for reading and writing file data.