Module block

Module block 

Block metadata stored in the footer.

Each block in the data region has a BlockMeta entry that records its physical location in the file and compression information.

Structs

ArchivedBlockMeta
An archived BlockMeta
BlockMeta
Metadata for a single block in the data region.
BlockMetaResolver
The resolver for an archived BlockMeta

Enums

ArchivedCodecId
An archived CodecId
CodecId
Identifies which compression codec was used for a block.
CodecIdResolver
The resolver for an archived CodecId