Block metadata stored in the footer.
Each block in the data region has a BlockMeta entry that records
its physical location in the file and compression information.
Structs
- Archived
Block Meta - An archived
BlockMeta - Block
Meta - Metadata for a single block in the data region.
- Block
Meta Resolver - The resolver for an archived
BlockMeta
Enums
- Archived
Codec Id - An archived
CodecId - CodecId
- Identifies which compression codec was used for a block.
- Codec
IdResolver - The resolver for an archived
CodecId