Compression codec trait and built-in implementations.
The CompressionCodec trait allows plugging in different compression
algorithms. The footer records which codec was used per block via
CodecId, so the reader must be configured
with a codec that can handle all codec ids present in the file.
Structs
- Lz4Codec
- LZ4 compression codec using
lz4_flex. - NoCompression
- A no-op codec that stores blocks uncompressed.
- Zstd
Codec - Zstandard compression codec.
Traits
- Compression
Codec - A compression codec that can compress and decompress block data.
Functions
- decompress_
by_ id - Decompresses
databy dispatching on theCodecIdstored in the block footer.