Re-exports
pub use cache::DeltaCache;
Modules
Structs
- Allocator
Output - The output of
DeltaAllocator::commit: a file handle to the compressed block bytes (seeked to the start), the total byte count, and the block metadata table. - Delta
- Delta
Allocator - Packs raw chunk bytes into compressed blocks.
- Delta
Immutable - Delta
Mutable