pub struct Delta<D> {
pub inner: D,
}Fields
inner: DImplementations
Sourceimpl Delta<DeltaImmutable>
impl Delta<DeltaImmutable>
Sourceimpl Delta<DeltaMutable>
impl Delta<DeltaMutable>
pub fn new( codec: Arc<dyn CompressionCodec>, block_target_size: usize, delta_index: u32, ) -> Self
pub fn define_array( &mut self, name: impl Into<String>, dtype: DType, shape: Vec<usize>, dimension_names: Vec<String>, chunk_shape: Option<Vec<usize>>, fill_value: Option<FillValue>, ) -> Result<()>
pub fn array_meta(&self, name: &str) -> Option<&ArrayMeta>
Sourcepub fn write_raw_chunk(
&mut self,
name: &str,
coord: Vec<u32>,
raw: &[u8],
) -> Result<()>
pub fn write_raw_chunk( &mut self, name: &str, coord: Vec<u32>, raw: &[u8], ) -> Result<()>
Allocates chunk bytes and records the chunk address in the array meta.
Sourcepub fn array_meta_mut(&mut self, name: &str) -> Option<&mut ArrayMeta>
pub fn array_meta_mut(&mut self, name: &str) -> Option<&mut ArrayMeta>
Returns a mutable reference to the ArrayMeta for name, if present.
Sourcepub fn upsert_array_meta(&mut self, meta: ArrayMeta)
pub fn upsert_array_meta(&mut self, meta: ArrayMeta)
Inserts or replaces the ArrayMeta for meta.name.
Sourcepub fn mark_deleted(&mut self, meta: ArrayMeta)
pub fn mark_deleted(&mut self, meta: ArrayMeta)
Stamps meta as deleted, clears its chunks, and upserts it.
Sourcepub fn intern_attr_key(&mut self, key: &str) -> usize
pub fn intern_attr_key(&mut self, key: &str) -> usize
Interns key into the attribute key dictionary, returning its index.
Sourcepub fn intern_attr_value(&mut self, value: AttributeValue) -> usize
pub fn intern_attr_value(&mut self, value: AttributeValue) -> usize
Interns value into the attribute value dictionary, returning its index.